@@ -1,8 +1,8 @@
 #!/bin/sh
 
 #
-# DaVinci Resolve 16.2 Debian package creator
-# Release 2020-03-06
+# DaVinci Resolve 16.2.2 Debian package creator
+# Release 2020-05-19
 # By Daniel Tufvesson
 #
 
@@ -27,16 +27,8 @@ copy_object() {
 }
 
 link_object() {
-    if [ -e "$1" ] ; then
-	echo "[LINK] $2 [TO] $1"
-	ln -s "$1" "$2"
-	if [ $? -ne 0 ] ; then
-	    ERRORS=$((ERRORS+1))
-	fi
-    else
-	echo "[ERROR: MISSING] $1"
-	ERRORS=$((ERRORS+1))
-    fi
+    echo "[LINK] $2 [TO] $1"
+    ln -s "$1" "$2"
 }
 
 create_directory() {
@@ -70,8 +62,8 @@ make_executable() {
 }
 
 # Setup variables
-RESOLVE_VERSION=16.2
-DEB_STEPPING=2
+RESOLVE_VERSION=16.2.2
+DEB_STEPPING=1
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
@@ -113,7 +105,8 @@ check_command xorriso
 xorriso -osirrox on -indev ${INSTALLER_ARCHIVE} -extract / ${UNPACK_DIR}
 
 # Create destination directories
-if [ -e "${UNPACK_DIR}" ] ; then
+if [ -e "${DEB_DIR}" ] ; then
+    chmod a+w -R ${DEB_DIR}
     rm -rf ${DEB_DIR}
 fi
 create_directory ${DEB_DIR}
@@ -124,6 +117,7 @@ create_directory ${RESOLVE_BASE_DIR}/easyDCP
 create_directory ${RESOLVE_BASE_DIR}/scripts
 create_directory ${RESOLVE_BASE_DIR}/.license
 create_directory ${RESOLVE_BASE_DIR}/share
+create_directory ${RESOLVE_BASE_DIR}/Fairlight
 
 # Copy objects
 copy_object ${UNPACK_DIR}/bin ${RESOLVE_BASE_DIR}
@@ -155,12 +149,9 @@ cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
 SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
 EOF
 
-# Fix missing x flag
-#chmod +x ${RESOLVE_BASE_DIR}/bin/DaVinciPanelDaemon
-
-# Install panel API library
-create_directory ${DEB_DIR}/usr/lib/x86_64-linux-gnu
-extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/x86_64-linux-gnu libDaVinciPanelAPI.so
+# Extract panel API library
+create_directory ${DEB_DIR}/usr/lib
+extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libDaVinciPanelAPI.so
 
 # Create symlinks
 create_directory ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
@@ -201,19 +192,11 @@ cat > ${DEB_DIR}/DEBIAN/postinst <<EOF
 chmod -R a+rw /opt/resolve/easyDCP
 chmod -R a+rw /opt/resolve/LUT
 chmod -R a+rw /opt/resolve/.license
+chmod -R a+rw /opt/resolve/Fairlight
 chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
-test ! -e /usr/lib64 && mkdir /usr/lib64 && touch /usr/lib64.by.makeresolvedeb
-test ! -h /usr/lib64/libDaVinciPanelAPI.so && ln -s /usr/lib/x86_64-linux-gnu/libDaVinciPanelAPI.so /usr/lib64/libDaVinciPanelAPI.so
 exit 0
 EOF
 make_executable ${DEB_DIR}/DEBIAN/postinst
-cat > ${DEB_DIR}/DEBIAN/postrm <<EOF
-#!/bin/sh
-test -h /usr/lib64/libDaVinciPanelAPI.so && rm /usr/lib64/libDaVinciPanelAPI.so
-test -e /usr/lib64.by.makeresolvedeb && rmdir /usr/lib64 && rm /usr/lib64.by.makeresolvedeb
-exit 0
-EOF
-make_executable ${DEB_DIR}/DEBIAN/postrm
 check_command fakeroot
 check_command dpkg-deb
 fakeroot dpkg-deb -b ${DEB_DIR} ${DEB_DIR}.deb
@@ -222,6 +205,7 @@ if [ $? -ne 0 ] ; then
 fi
 
 # Clean up
+chmod a+w -R ${DEB_DIR}
 rm -rf ${DEB_DIR}
 chmod a+w -R ${UNPACK_DIR}
 rm -rf ${UNPACK_DIR}
